summaryrefslogtreecommitdiff
path: root/src/util/util.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/util/util.c')
-rw-r--r--src/util/util.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/util/util.c b/src/util/util.c
index fa0a71f6a..c9fd5a81f 100644
--- a/src/util/util.c
+++ b/src/util/util.c
@@ -546,22 +546,22 @@ TALER_url_absolute_mhd (struct MHD_Connection *connection,
/**
* Obtain the payment method from a @a payto_url
*
* @param payto_url the URL to parse
* @return NULL on error (malformed @a payto_url)
*/
char *
-TALER_payto_get_method (const char *payto_url)
+TALER_payto_get_method (const char *payto_uri)
{
const char *start;
const char *end;
- if (0 != strncmp (payto_url,
+ if (0 != strncmp (payto_uri,
PAYTO,
strlen (PAYTO)))
return NULL;
- start = &payto_url[strlen (PAYTO)];
+ start = &payto_uri[strlen (PAYTO)];
end = strchr (start,
(unsigned char) '/');
if (NULL == end)
@@ -546,22 +546,22 @@ TALER_url_absolute_mhd (struct MHD_Connection *connection,
/**
- * Obtain the payment method from a @a payto_url
+ * Obtain the payment method from a @a payto_uri
*
@@ -546,22 +546,22 @@ TALER_url_absolute_mhd (struct MHD_Connection *connection,
*
- * @param payto_url the URL to parse
- * @return NULL on error (malformed @a payto_url)
+ * @param payto_uri the URL to parse
+ * @return NULL on error (malformed @a payto_uri)
*/
char *